from boto3.session import Session
from botocore.config import Config
from django.conf import settings

session = Session(
    aws_access_key_id=settings.PONOS_AWS_ACCESS_KEY,
    aws_secret_access_key=settings.PONOS_AWS_SECRET_KEY,
)

config = Config(
    region_name=settings.PONOS_AWS_REGION,
    signature_version="s3v4",
)

s3 = session.resource(
    "s3",
    endpoint_url=settings.PONOS_AWS_ENDPOINT,
    config=config,
)


def object_url(action: str, s3_obj) -> str:
    """
    Helper to obtain a presigned URL for a client method such as ``get_object``
    on an S3 Object instance.
    """
    return s3.meta.client.generate_presigned_url(
        action, Params={"Bucket": s3_obj.bucket_name, "Key": s3_obj.key}
    )
