import os
from uuid import UUID


def get_ponos_run():
    """
    Obtain the Ponos run number inside a task from the environment variables,
    provided the agent implementation sets the ``PONOS_RUN`` variable.

    :returns: A positive or zero integer representing the task's run,
       or None if ``PONOS_RUN`` was not defined.
    """
    value = os.environ.get("PONOS_RUN")
    if value is None:
        return
    return int(value)


def get_ponos_task_id():
    """
    Obtain the Ponos task ID when running inside a task from an environment variable,
    provided the agent implementation sets the ``PONOS_TASK`` variable.

    :returns: An UUID representing the task's ID,
       or None if ``PONOS_TASK`` was not deefined.
    """
    value = os.environ.get("PONOS_TASK")
    if not value:
        return
    return UUID(value)


def is_ponos_task() -> bool:
    """
    Check whether this process is running inside a Ponos task container.
    """
    return isinstance(get_ponos_task_id(), UUID)
