# Generated by Django 2.1.7 on 2019-06-21 09:31

from django.db import migrations
from django.db.models import Count


def parent_to_parents(apps, schema_editor):
    db_alias = schema_editor.connection.alias
    Task = apps.get_model("ponos", "Task")
    TaskParent = Task.parents.through

    new_parents = []
    for task in (
        Task.objects.using(db_alias).exclude(parent=None).only("id", "parent_id")
    ):
        new_parents.append(
            TaskParent(
                from_task_id=task.id,
                to_task_id=task.parent_id,
            )
        )
    TaskParent.objects.using(db_alias).bulk_create(new_parents)


def parents_to_parent(apps, schema_editor):
    db_alias = schema_editor.connection.alias
    Task = apps.get_model("ponos", "Task")
    assert (
        not Task.objects.using(db_alias)
        .annotate(parents_count=Count("parents"))
        .filter(parents_count__gt=1)
        .exists()
    ), "Cannot migrate task with multiple parents backwards"

    for task in Task.objects.using(db_alias).filter(parents__isnull=False):
        task.parent = task.parents.get()
        task.save()


class Migration(migrations.Migration):

    dependencies = [
        ("ponos", "0006_add_parents"),
    ]

    operations = [
        migrations.RunPython(
            parent_to_parents,
            parents_to_parent,
        ),
    ]
